@@ -23,6 +23,7 @@
   obj = [super createBegin: aZone];
   obj->springLength = DEFAULT_SPRING_LENGTH;
   obj->randPosSeed = DEFAULT_RANDOM_SEED;
+  obj->nodeList = [List create: aZone];
 
   return obj;
 }
@@ -64,12 +65,6 @@
   return self;
 }
 
-- createEnd
-{
-  nodeList = [List create: [self getZone]];
-  return self;
-}
-
 - showCanvas: aCanvas
 {
    id index, node;
